<?php

/*
 * This file is part of the AuthStack project.
 *
 * (c) Buckhill Ltd <development@buckhill.co.uk>
 *
 * This source file is subject to the Buckhill license that is bundled
 * with this source code in the file LICENSE.
 */

namespace  AuthStack\TwoFactor\Model;

use AuthStack\TwoFactor\Model\Key;
use Illuminate\Database\Eloquent\Model;

class SecurityKey extends Model
{
    protected $table = 'security_keys';
    public $timestamps = false;
    protected $fillable = ['user_id', 'key_id', 'confirmed'];
}
