<?php

namespace AuthStack\TwoFactor\Model\U2F;

use Illuminate\Database\Eloquent\Model;

class Authentication extends Model
{
    protected $table = 'mfa_u2f_auth';
    public $timestamps = true;
    protected $fillable = ['key_id', 'challenge', 'version', 'created_at', 'updated_at'];
}